@@ -1,9 +1,9 @@
-from django.conf.urls import patterns, url
+from django.conf.urls import url
 
 from .views import SubmitView, ThanksView
 
 
-urlpatterns = patterns('',
+urlpatterns = [
     url(r'^$', SubmitView.as_view(), name='form'),
     url(r'^thanks/$', ThanksView.as_view(), name='thanks'),
-)
+]
